@@ -27,7 +27,7 @@ class AbstractNamedEmailUser(AbstractEmailUser):
         abstract = True
 
     def __str__(self):
-        return f"{self.first_name} {self.last_name}"
+        return f"{self.email} - {self.first_name} {self.last_name}"
 
 
 class NamedEmailUser(AbstractNamedEmailUser):
